pub trait AutomationHooks: Send + Sync {
// Required methods
fn draft_task<'life0, 'async_trait>(
&'life0 self,
request: DraftRequest,
) -> Pin<Box<dyn Future<Output = Result<DraftResult>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn draft_schedule<'life0, 'async_trait>(
&'life0 self,
request: DraftRequest,
) -> Pin<Box<dyn Future<Output = Result<DraftResult>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Defines the behavior required from a automation hooks participant in the tools workflow.
Required Methods
Sourcefn draft_task<'life0, 'async_trait>(
&'life0 self,
request: DraftRequest,
) -> Pin<Box<dyn Future<Output = Result<DraftResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn draft_task<'life0, 'async_trait>(
&'life0 self,
request: DraftRequest,
) -> Pin<Box<dyn Future<Output = Result<DraftResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates an internal task draft for staff review rather than directly assigning labor or changing schedules.
Sourcefn draft_schedule<'life0, 'async_trait>(
&'life0 self,
request: DraftRequest,
) -> Pin<Box<dyn Future<Output = Result<DraftResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn draft_schedule<'life0, 'async_trait>(
&'life0 self,
request: DraftRequest,
) -> Pin<Box<dyn Future<Output = Result<DraftResult>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates a schedule-change draft for manager review rather than mutating staff rosters.